<?php
/*
Plugin Name: Dynamic CTA
Plugin URI: http://dynamicctas.com
Description: First dynamic CTAs tool - the plugin monitors and records each visitor browsing history on your website and publishes custom CTAs as the rules and flows defined by you.
Author: Gabriel Vieira
Version: 1.0.1
Author URI: http://dynamicctas.com
License: All rights reserved
Text Domain: dynamic-ctas
Domain Path: /languages/
*/
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

function dynamic_cta_load_plugin_textdomain() {
	load_plugin_textdomain( 'dynamic-ctas', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'dynamic_cta_load_plugin_textdomain' );

/**
 * Register a custom menu page.
 */
function dynamic_cta_menu_page_register(){
	add_menu_page(
		__( 'Dynamic CTAs', 'dynamic-ctas' ),
		__( 'Dynamic CTAs', 'dynamic-ctas' ),
		'manage_options',
		'dynamic_cta_page',
		'dynamic_cta_menu_page',
		plugins_url( 'image/logoDynamicCTA.png', __FILE__ ),
		6
	);
	add_submenu_page('dynamic_cta_page', __( 'All CTA', 'dynamic-ctas' ), __( 'All CTA', 'dynamic-ctas' ), 'manage_options', 'dynamic_cta_page' );

	$loop = new WP_Query(array('post_type' => 'dynamic_cta_type'));
	if ($loop->post_count > 3){
		$count = 0;
		while ( $loop->have_posts() ){
			if ($count++ > 2) {
				wp_delete_post(get_the_ID(), true);
				break;
			}
		}
	}
	if ($loop->post_count < 3){
		add_submenu_page('dynamic_cta_page', __( 'New CTA', 'dynamic-ctas' ), __( 'New CTA', 'dynamic-ctas' ),'manage_options','post-new.php?post_type=dynamic_cta_type');
	}
}
add_action( 'admin_menu', 'dynamic_cta_menu_page_register' );

/**
 * Display a custom menu page
 */
function dynamic_cta_menu_page(){
	include('dynamic_ctas_admin.php');
}

// Creating the widget
class dynamic_cta_widget extends WP_Widget{
	private static $inited;

	function __construct(){
		parent::__construct(
			'ea_dynamicCtas_widget',// Base ID of your widget
			__('Dynamic CTA', 'dynamic-ctas'),// Widget name will appear in UI
			array('description' => __('Dynamic CTA', 'dynamic-ctas'),)// Widget description
		);
	}

	// Creating widget front-end
	public function widget($args, $instance){
		if (is_null(self::$inited)) { // only on first run
			self::$inited = true;
		} else {
			return;
		}
		echo __(dynamic_cta_function($instance), 'dynamic-ctas');
	}

	// Widget Backend
	public function form($instance)	{
		$newArray = get_option( 'widget_ea_dynamicctas_widget' );
		if (count($newArray) > 2){
			echo '<p>'.__( 'It is allowed only one widget in starter version. Thus it appears only the first.', 'dynamic-ctas' ).'</p>';
		}

		if (isset($instance['flux'])) {
			$flux = $instance['flux'];
		}
		// Widget admin form
		?>
		<p>
			<label for="<?php echo $this->get_field_id('flux'); ?>"><?php echo __( 'Flux', 'dynamic-ctas' ); ?>:</label>
			<p><?php echo __( 'Free Version - Only one flux', 'dynamic-ctas' );?></p>
		</p>
		<?php
	}

	// Updating widget replacing old instances with new
	public function update($new_instance, $old_instance){
		$instance = array();
		$instance['flux'] = (!empty($new_instance['flux'])) ? strip_tags($new_instance['flux']) : '';
		return $instance;
	}

}

// Register and load the widget
function dynamic_cta_load_widget(){
	register_widget('dynamic_cta_widget');
}

add_action('widgets_init', 'dynamic_cta_load_widget');

function dynamic_cta_function($instance){
	if (isset($instance['flux'])) {
		$flux = $instance['flux'];
	}else{
		$flux = 0;
	}?>
	<div class="dynamicCtas" id="dynamicCtas">
		<?php
		dynamic_cta_SetCookie_function();
		$menu_order = ($_COOKIE['dynamicCtas']) ? $_COOKIE['dynamicCtas'] : 0;
		$loop = new WP_Query(array(
			'posts_per_page' => 1,
			'post_type' => 'dynamic_cta_type',
			'menu_order' => $menu_order
		));
		while ( $loop->have_posts() ) {
			$loop->the_post();
			echo the_content();
		}
		?>
	</div>
	<?php
}
//To get future works easy, put a shortcode
add_shortcode('dynamicCtas', 'dynamic_cta_function');

//add a post type for the widget works well
add_action( 'init', 'dynamic_cta_type_function' );
function dynamic_cta_type_function() {
	$args = array(
		'labels' => array(
			'name' => __( 'Dynamic CTAs', 'dynamic-ctas' ),
			'singular_name' => __( 'Dynamic CTA', 'dynamic-ctas' ),
			'post_title' => __( 'Dynamic CTAs', 'dynamic-ctas' ),
			'add_new_item' => __( 'Add new CTA', 'dynamic-ctas' )
		),
		'public' => true,
		'publicly_queryable' => true,
		'show_ui' => true,
		'query_var' => true,
		'rewrite' => true,
		'show_in_menu' => false,
		'capability_type' => 'post',
		'hierarchical' => false,
		'menu_position' => null,
		'supports' => array('title', 'editor', 'page-attributes'),
	);
	register_post_type( 'dynamic_cta_type' , $args );
}

//function to set properly the cookie, as rules defined
function dynamic_cta_SetCookie_function(){
	if(!isset($_COOKIE['dynamicCtas'])) {
		setcookie('dynamicCtas', '0', time() + 3600, COOKIEPATH, COOKIE_DOMAIN);
		$_COOKIE['dynamicCtas'] = '0';//just to set cookie on the fly
	}else{
		$selfURL = dynamic_cta_selfURL();
		$loop = new WP_Query(array(
			'post_type' => 'dynamic_cta_type'
		));

		while ( $loop->have_posts() ) {
			$loop->the_post();
			$tittleToLook = explode(' ', the_title(null, null, false));

			foreach($tittleToLook as $look){
				if ($look != ''){
					$thispost = get_post(get_the_ID());
					$menu_order = $thispost->menu_order;
					if (strpos($selfURL, $look) !== false && $menu_order > $_COOKIE['dynamicCtas']) {
						setcookie('dynamicCtas', $menu_order, time() + 3600, COOKIEPATH, COOKIE_DOMAIN);
						$_COOKIE['dynamicCtas'] = $menu_order;//just to set new cookie on the fly
					}
				}
			}
		}
	}
}
//to properly set cookie the best way is using init function instead using a shortcode, but I leave below to get noted
add_action( 'wp_loaded', 'dynamic_cta_SetCookie_function' );
//add_shortcode('dynamicCtas', 'dynamicCtasSetCookie_function');

//to get self URL properly
function dynamic_cta_selfURL(){
	$s = empty($_SERVER["HTTPS"]) ? '' : ($_SERVER["HTTPS"] == "on") ? "s" : "";
	$protocol = strleft(strtolower($_SERVER["SERVER_PROTOCOL"]), "/").$s;
	$port = ($_SERVER["SERVER_PORT"] == "80") ? "" : (":".$_SERVER["SERVER_PORT"]);
	return $protocol."://".$_SERVER['SERVER_NAME'].$port.$_SERVER['REQUEST_URI'];
}

function strleft($s1, $s2) { return substr($s1, 0, strpos($s1, $s2)); }
//////


//add order column to admin listing screen for header text
function dynamic_cta_type_column($dynamic_cta_type_columns) {
	$dynamic_cta_type_columns['menu_order'] = "Order";
	return $dynamic_cta_type_columns;
}
add_action('manage_edit-dynamic_cta_type_columns', 'dynamic_cta_type_column');

//show custom order column values
function dynamic_cta_show_order_column($name){
	global $post;

	switch ($name) {
		case 'menu_order':
			$order = $post->menu_order;
			echo $order;
			break;
		default:
			break;
	}
}
add_action('manage_dynamic_cta_type_posts_custom_column','dynamic_cta_show_order_column');

//make column sortable
function dynamic_cta_order_column_register_sortable($columns){
	$columns['menu_order'] = 'menu_order';
	return $columns;
}
add_filter('manage_edit-dynamic_cta_type_sortable_columns','dynamic_cta_order_column_register_sortable');

function dynamic_cta_stop_change_default_title( $title ) {
	$screen = get_current_screen();
	if( isset( $screen->post_type ) ) {
		if ( 'dynamic_cta_type' == $screen->post_type ) {
			$title = __( 'Enter here your watching words or URL, separated by space', 'dynamic-ctas' );
		}
	}
	return $title;
}
add_filter( 'enter_title_here', 'dynamic_cta_stop_change_default_title' );

function dynamic_cta_load_scripts() {
	$screen = get_current_screen();
	if( isset( $screen->post_type ) ) {
		if ( 'dynamic_cta_type' == $screen->post_type ) {
			echo '<script type="text/javascript">';
			echo 'var dynamic_ctas_url = "'.plugins_url( '', __FILE__ ).'";';
			echo '</script>';
			wp_enqueue_script( 'custom-js', plugins_url( '', __FILE__ ) . '/dynamic_ctas_script.js', array( 'jquery' ), '1.1', true );
		}else{
			return;
		}
	}
}
add_action('admin_enqueue_scripts', 'dynamic_cta_load_scripts');